@@ -26,19 +26,19 @@
 #include "packet.h"
 #include "routes.h"
 
-#ifdef WIN32
+#ifdef _WIN32
 #define close(x) closesocket(x)
 #undef errno
 #define errno WSAGetLastError()
 #undef strerror
 #define strerror(x) StrError(x)
 #define perror(x) WinSockPError(x)
-#endif
+#endif /* _WIN32 */
 
 int ipc_socket = 0;
 
 int
-ipc_close()
+ipc_close(void)
 {
 
   if (close(ipc_socket))
@@ -50,12 +50,12 @@ ipc_close()
 int
 ipc_connect(struct sockaddr_in *pin)
 {
-#ifdef WIN32
+#ifdef _WIN32
   int On = 1;
   unsigned long Len;
-#else
+#else /* _WIN32 */
   int flags;
-#endif
+#endif /* _WIN32 */
 
   connected = 0;
 
@@ -73,17 +73,17 @@ ipc_connect(struct sockaddr_in *pin)
     set_net_info_offline();
     printf("connection refused\n");
   } else {
-    set_net_info("Connected!", FALSE);
+    set_net_info((gchar *)"Connected!", FALSE);
     printf("Connected!!\n");
 
     /* Setting socket non-blocking */
 
-#ifdef WIN32
+#ifdef _WIN32
     if (WSAIoctl(ipc_socket, FIONBIO, &On, sizeof(On), NULL, 0, &Len, NULL, NULL) < 0) {
       fprintf(stderr, "Error while making socket non-blocking!\n");
       exit(1);
     }
-#else
+#else /* _WIN32 */
     if ((flags = fcntl(ipc_socket, F_GETFL, 0)) < 0) {
       fprintf(stderr, "Error getting socket flags!\n");
       exit(1);
@@ -93,7 +93,7 @@ ipc_connect(struct sockaddr_in *pin)
       fprintf(stderr, "Error setting socket flags!\n");
       exit(1);
     }
-#endif
+#endif /* _WIN32 */
     connected = 1;
 
     return 1;
@@ -104,7 +104,7 @@ ipc_connect(struct sockaddr_in *pin)
 }
 
 int
-ipc_read()
+ipc_read(void)
 {
   //int x, i;
   int bytes, tmp_len;
@@ -117,14 +117,14 @@ ipc_read()
   //char buf[BUFFSIZE+1];
 
   //printf(".");fflush(stdout);
-  memset(&inbuf, 0, sizeof(BUFFSIZE + 1));
+  memset(&inbuf, 0, sizeof(inbuf));
   //buf[0] = '\0';
 
   if (connected) {
     bytes = recv(ipc_socket, (char *)&inbuf, BUFFSIZE, 0);
     if (bytes == 0) {
       shutdown(ipc_socket, SHUT_RDWR);
-      set_net_info("Disconnected from server...", TRUE);
+      set_net_info((gchar *)"Disconnected from server...", TRUE);
       connected = 0;
       close(ipc_socket);
     }
@@ -176,7 +176,7 @@ ipc_read()
             //printf("READING END OF MESSAGE. %d bytes\n", tmp_len-bytes);
             //printf("\tCopying %d bytes\n", bytes);
             memcpy(&inbuf, tmp, bytes);
-            //printf("\tRecieving %d bytes to buffer[%d]\n", tmp_len-bytes, bytes);
+            //printf("\tReceiving %d bytes to buffer[%d]\n", tmp_len-bytes, bytes);
             bytes = recv(ipc_socket, (char *)&inbuf.buf[bytes], tmp_len - bytes, 0);
             //printf("\tBytes: %d Size: %d\n", bytes, ntohs(msgs->v4.olsr_packlen));
             tmp = (char *)&inbuf.olsr_msg;
@@ -197,7 +197,7 @@ ipc_read()
 }
 
 int
-ipc_send()
+ipc_send(void)
 {
 
   return 1;
@@ -223,9 +223,9 @@ ipc_evaluate_message(union olsr_message *olsr_in)
 
   switch (type) {
   case HELLO_MESSAGE:
-    //printf("Recieved HELLO packet\n");
+    //printf("Received HELLO packet\n");
     if (!freeze_packets)
-      packet_list_add("HELLO", ip_to_string(originator), itoa_buf);
+      packet_list_add((char *)"HELLO", ip_to_string(originator), itoa_buf);
 
     if (ipversion == AF_INET) {
       process_hello(msgsize, vtime, originator, (union hello_message *)&olsr_in->v4.message.hello);
@@ -236,26 +236,26 @@ ipc_evaluate_message(union olsr_message *olsr_in)
 
   case TC_MESSAGE:
     if (!freeze_packets)
-      packet_list_add("TC", ip_to_string(originator), itoa_buf);
+      packet_list_add((char *)"TC", ip_to_string(originator), itoa_buf);
 
     if (ipversion == AF_INET) {
       process_tc(msgsize, vtime, originator, (union tc_message *)&olsr_in->v4.message.tc);
-      //printf("Recieved TC packet from %s\n", ip_to_string(&m->olsr_tc->tc_origaddr));
+      //printf("Received TC packet from %s\n", ip_to_string(&m->olsr_tc->tc_origaddr));
     } else {
       process_tc(msgsize, vtime, originator, (union tc_message *)&olsr_in->v6.message.tc);
-      //printf("Recieved TC packet from %s\n", ip_to_string(&m->olsr_tc->tc_origaddr));
+      //printf("Received TC packet from %s\n", ip_to_string(&m->olsr_tc->tc_origaddr));
     }
     break;
 
   case MID_MESSAGE:
     if (!freeze_packets)
-      packet_list_add("MID", ip_to_string(originator), itoa_buf);
+      packet_list_add((char *)"MID", ip_to_string(originator), itoa_buf);
     if (ipversion == AF_INET) {
       process_mid(msgsize, vtime, originator, (union mid_message *)&olsr_in->v4.message.mid);
-      //printf("Recieved MID packet from %s\n", ip_to_string(&m->olsr_mid->mid_origaddr));
+      //printf("Received MID packet from %s\n", ip_to_string(&m->olsr_mid->mid_origaddr));
     } else {
       process_mid(msgsize, vtime, originator, (union mid_message *)&olsr_in->v6.message.mid);
-      //printf("Recieved MID packet from %s\n", ip_to_string(&m->olsr_mid->mid_origaddr));
+      //printf("Received MID packet from %s\n", ip_to_string(&m->olsr_mid->mid_origaddr));
     }
 
     break;
@@ -263,24 +263,24 @@ ipc_evaluate_message(union olsr_message *olsr_in)
   case HNA_MESSAGE:
 
     if (!freeze_packets)
-      packet_list_add("HNA", ip_to_string(originator), itoa_buf);
+      packet_list_add((char *)"HNA", ip_to_string(originator), itoa_buf);
     if (ipversion == AF_INET) {
       process_hna(msgsize, vtime, originator, (union hna_message *)&olsr_in->v4.message.hna);
-      //printf("Recieved HNA packet\n");
+      //printf("Received HNA packet\n");
     } else {
       process_hna(msgsize, vtime, originator, (union hna_message *)&olsr_in->v6.message.hna);
-      //printf("Recieved HNA packet\n");
+      //printf("Received HNA packet\n");
     }
 
     break;
 
   case IPC_MESSAGE:
-    //printf("Recieved IPC packet\n");
+    //printf("Received IPC packet\n");
     ipc_pack = 1;               /* Don't add to buffer */
     ipc_eval_route_packet((struct routemsg *)olsr_in);
     break;
   case IPC_NET:
-    //printf("Recieved IPC packet\n");
+    //printf("Received IPC packet\n");
     ipc_pack = 1;               /* Don't add to buffer */
     ipc_eval_net_info((struct netmsg *)olsr_in);
     break;
@@ -291,7 +291,7 @@ ipc_evaluate_message(union olsr_message *olsr_in)
       packet_list_add(unk_label, ip_to_string(originator), itoa_buf);
     }
     printf("Unknown packet type %d\n", type);
-
+    break;
   }
 
   if (!freeze_packets && !ipc_pack) {
@@ -309,8 +309,8 @@ ipc_eval_net_info(struct netmsg *msg)
 
   /*
      printf("\tMain address: %s\n", ip_to_string(&msg->main_addr));
-     printf("\tMid adresses: %d\n", msg->mids);
-     printf("\tHna adresses: %d\n", msg->hnas);
+     printf("\tMid addresses: %d\n", msg->mids);
+     printf("\tHna addresses: %d\n", msg->hnas);
      printf("\tHELLO interval: %f\n", (float)(ntohs(msg->hello_int)));
      printf("\tHELLO LAN interval: %f\n", (float)(ntohs(msg->hello_lan_int)));
      printf("\tTC interval: %d\n", ntohs(msg->tc_int));
@@ -396,7 +396,8 @@ process_hello(int size, olsr_u8_t vtime, union olsr_ip_addr *originator, union h
   struct hellinfo6 *neigh6;
   int i;
   int nsize;
-  int type, link;
+  int type;
+  //int link;
 
   printf("Processing HELLO from %s size = %d\n", ip_to_string(originator), size);
 
@@ -421,12 +422,12 @@ process_hello(int size, olsr_u8_t vtime, union olsr_ip_addr *originator, union h
     if (ipversion == AF_INET) {
       nsize = ntohs(neigh->size);
       type = EXTRACT_STATUS(ntohs(neigh->link_code));
-      link = EXTRACT_LINK(ntohs(neigh->link_code));
+      //link = EXTRACT_LINK(ntohs(neigh->link_code));
       //printf("TYPE: %d\n", neigh->link_code);
     } else {
       nsize = ntohs(neigh6->size);
       type = EXTRACT_STATUS(ntohs(neigh6->link_code));
-      link = EXTRACT_LINK(ntohs(neigh6->link_code));
+      //link = EXTRACT_LINK(ntohs(neigh6->link_code));
     }
 
     size -= nsize;
@@ -472,8 +473,8 @@ int
 process_tc(int size, olsr_u8_t vtime, union olsr_ip_addr *originator, union tc_message *m)
 {
 
-  struct neigh_info *mprsinfo;
-  struct neigh_info6 *mprsinfo6;
+  struct neigh_info *mprsinfo = NULL;
+  struct neigh_info6 *mprsinfo6 = NULL;
 
   printf("Processing TC from %s size = %d\n", ip_to_string(originator), size);
 
@@ -515,8 +516,8 @@ process_tc(int size, olsr_u8_t vtime, union olsr_ip_addr *originator, union tc_m
 int
 process_mid(int size, olsr_u8_t vtime, union olsr_ip_addr *originator, union mid_message *m)
 {
-  struct midaddr *midaddr;
-  struct midaddr6 *midaddr6;
+  struct midaddr *midaddr = NULL;
+  struct midaddr6 *midaddr6 = NULL;
 
   printf("Processing MID from %s size = %d\n", ip_to_string(originator), size);
 
@@ -550,10 +551,10 @@ process_mid(int size, olsr_u8_t vtime, union olsr_ip_addr *originator, union mid
 int
 process_hna(int size, olsr_u8_t vtime, union olsr_ip_addr *originator, union hna_message *m)
 {
+  struct hnapair *hnapairs = NULL;
+  struct hnapair6 *hnapairs6 = NULL;
 
   printf("Processing HNA size = %d\n", size);
-  struct hnapair *hnapairs;
-  struct hnapair6 *hnapairs6;
 
   /* Calculate size of the hnainfo */
   size = size - 4 - 4 - ipsize;
@@ -586,7 +587,7 @@ ip_to_string(union olsr_ip_addr *addr)
   struct in_addr in;
 
   if (ipversion == AF_INET) {
-    in.s_addr = addr->v4;
+    in = addr->v4;
     ret = inet_ntoa(in);
   } else {
     /* IPv6 */
@@ -602,9 +603,9 @@ gui_itoa(int i, char *buf)
 {
   char tmp[10];
 
-  if (sprintf(buf, "%hd", i)) {
+  if (snprintf(buf, sizeof(tmp), "%hd", i)) {
     /* This shitty string needs to be converted to UTF-8 */
-    strcpy(tmp, g_locale_to_utf8(buf, -1, NULL, NULL, NULL));
+    snprintf(tmp, sizeof(tmp), "%s", g_locale_to_utf8(buf, -1, NULL, NULL, NULL));
     strcpy(buf, tmp);
     return 1;
     //return ret;
