@@ -38,6 +38,8 @@
  *
  */
 
+#ifdef _WIN32
+
 #include "stdafx.h"
 #include "Frontend.h"
 #include "MyDialog2.h"
@@ -46,7 +48,7 @@
 #define new DEBUG_NEW
 #undef THIS_FILE
 static char THIS_FILE[] = __FILE__;
-#endif
+#endif /* _DEBUG */
 
 #define MAXIF 100
 
@@ -241,11 +243,11 @@ int MyDialog2::OpenConfigFile(CString PathName)
 	if (Conf != NULL)
 		olsrd_free_cnf(Conf);
 
-	Conf = olsrd_parse_cnf(PathName);
-
-	if (Conf == NULL)
+	if (olsrd_parse_cnf(PathName) < 0)
 		return -1;
 
+	Conf = olsr_cnf;
+
 	for (i = 0; i < NumInt; i++)
 		m_InterfaceList.SetCheck(i, FALSE);
 
@@ -695,3 +697,5 @@ void MyDialog2::OnEtxRadio2()
 {
 	m_EtxRadio1.SetCheck(FALSE);
 }
+
+#endif /* _WIN32 */
