@@ -36,9 +36,10 @@
  * to the project. For more information see the website or contact
  * the copyright holders.
  *
- * $Id: MyTabCtrl.cpp,v 1.5 2007/03/27 03:01:06 tlopatic Exp $
  */
 
+#ifdef _WIN32
+
 #include "stdafx.h"
 #include "Frontend.h"
 #include "MyTabCtrl.h"
@@ -47,7 +48,7 @@
 #define new DEBUG_NEW
 #undef THIS_FILE
 static char THIS_FILE[] = __FILE__;
-#endif
+#endif /* _DEBUG */
 
 MyTabCtrl::MyTabCtrl()
 {
@@ -122,3 +123,5 @@ void MyTabCtrl::OnSelchange(NMHDR* pNMHDR, LRESULT* pResult)
 
 	*pResult = 0;
 }
+
+#endif /* _WIN32 */
