@@ -129,7 +129,7 @@ mapwrite_work(FILE * fmap)
     }
   }
   lookup_defhna_latlon(&ip);
-  sprintf(my_latlon_str, "%f,%f,%d", my_lat, my_lon, get_isdefhna_latlon());
+  sprintf(my_latlon_str, "%f,%f,%d", (double)my_lat, (double)my_lon, get_isdefhna_latlon());
   if (0 >
       fprintf(fmap, "Self('%s',%s,'%s','%s');\n", olsr_ip_to_string(&strbuf1, &olsr_cnf->main_addr), my_latlon_str,
               olsr_ip_to_string(&strbuf2, &ip), my_names->name)) {
@@ -167,7 +167,7 @@ mapwrite_work(FILE * fmap)
         if (0 >
             fprintf(fmap, "PLink('%s','%s',%s,%s,%s,%s);\n", olsr_ip_to_string(&strbuf1, &tc_edge->T_dest_addr),
                     olsr_ip_to_string(&strbuf2, &tc->addr), get_tc_edge_entry_text(tc_edge, ',', &lqbuffer2),
-                    get_linkcost_text(tc_edge->cost, OLSR_FALSE, &lqbuffer), lla, llb)) {
+                    get_linkcost_text(tc_edge->cost, false, &lqbuffer), lla, llb)) {
           return;
         }
       } else {
@@ -179,7 +179,7 @@ mapwrite_work(FILE * fmap)
         if (0 >
             fprintf(fmap, "Link('%s','%s',%s,%s);\n", olsr_ip_to_string(&strbuf1, &tc_edge->T_dest_addr),
                     olsr_ip_to_string(&strbuf2, &tc->addr), get_tc_edge_entry_text(tc_edge, ',', &lqbuffer2),
-                    get_linkcost_text(tc_edge->cost, OLSR_FALSE, &lqbuffer))) {
+                    get_linkcost_text(tc_edge->cost, false, &lqbuffer))) {
           return;
         }
       }
@@ -189,11 +189,11 @@ mapwrite_work(FILE * fmap)
   OLSR_FOR_ALL_TC_ENTRIES_END(tc);
 }
 
-#ifndef WIN32
+#ifndef _WIN32
 
 /*
  * Windows doesn't know fifo's AFAIK. We better write
- * to a file (done in nameservice.c, see #ifdef WIN32)
+ * to a file (done in nameservice.c, see #ifdef _WIN32)
  */
 
 static const char *the_fifoname = 0;
@@ -209,17 +209,20 @@ mapwrite_poll(void *context __attribute__ ((unused)))
     int fd = open(the_fifoname, O_WRONLY | O_NONBLOCK);
     if (0 <= fd) {
       /*
-       * Change to blocking, otherwhise expect fprintf errors
+       * Change to blocking, otherwise expect fprintf errors
        */
-      fcntl(fd, F_SETFL, O_WRONLY);
-      fout = fdopen(fd, "w");
-      if (0 != fout) {
-        mapwrite_work(fout);
-        fclose(fout);
-        /* Give pipe reader cpu slot to detect EOF */
-        usleep(1);
-      } else {
+      if (fcntl(fd, F_SETFL, O_WRONLY) == -1) {
         close(fd);
+      } else {
+        fout = fdopen(fd, "w");
+        if (0 != fout) {
+          mapwrite_work(fout);
+          fclose(fout);
+          /* Give pipe reader cpu slot to detect EOF */
+          usleep(1);
+        } else {
+          close(fd);
+        }
       }
     }
   }
@@ -233,13 +236,13 @@ mapwrite_init(const char *fifoname)
     unlink(fifoname);
     if (0 > mkfifo(fifoname, S_IWUSR | S_IRUSR | S_IRGRP | S_IROTH)) {
       OLSR_PRINTF(1, "mkfifo(%s): %s", fifoname, strerror(errno));
-      return OLSR_FALSE;
+      return false;
     } else {
       the_fifoname = fifoname;
       olsr_start_timer(100, 5, OLSR_TIMER_PERIODIC, &mapwrite_poll, NULL, 0);
     }
   }
-  return OLSR_TRUE;
+  return true;
 }
 
 void
@@ -251,7 +254,7 @@ mapwrite_exit(void)
     the_fifoname = 0;
   }
 }
-#endif
+#endif /* _WIN32 */
 
 /*
  * Local Variables:
