@@ -85,8 +85,8 @@
  */
 struct name_entry {
   union olsr_ip_addr ip;
-  olsr_u16_t type;
-  olsr_u16_t len;
+  uint16_t type;
+  uint16_t len;
   char *name;
   struct name_entry *next;             /* linked list */
 };
@@ -122,7 +122,7 @@ void olsr_expire_write_file_timer(void *);
 void olsr_namesvc_delete_db_entry(struct db_entry *);
 
 /* Parser function to register with the sceduler */
-olsr_bool olsr_parser(union olsr_message *, struct interface *, union olsr_ip_addr *);
+bool olsr_parser(union olsr_message *, struct interface *, union olsr_ip_addr *);
 
 /* callback for periodic timer */
 void olsr_namesvc_gen(void *);
@@ -135,17 +135,17 @@ struct name_entry *remove_nonvalid_names_from_list(struct name_entry *my_list, i
 
 void free_all_list_entries(struct list_node *);
 
-void decap_namemsg(struct name *from_packet, struct name_entry **to, olsr_bool * this_table_changed);
+void decap_namemsg(struct name *from_packet, struct name_entry **to, bool * this_table_changed);
 
-void insert_new_name_in_list(union olsr_ip_addr *, struct list_node *, struct name *, olsr_bool *, olsr_reltime);
+void insert_new_name_in_list(union olsr_ip_addr *, struct list_node *, struct name *, bool *, olsr_reltime);
 
-olsr_bool allowed_hostname_or_ip_in_service(const char *service_line, const regmatch_t * hostname_or_ip);
+bool allowed_hostname_or_ip_in_service(const char *service_line, const regmatch_t * hostname_or_ip);
 
 void update_name_entry(union olsr_ip_addr *, struct namemsg *, int, olsr_reltime);
 
 void write_hosts_file(void);
 
-void write_services_file(void);
+void write_services_file(bool writemacs);
 
 void write_resolv_file(void);
 
@@ -153,19 +153,19 @@ int register_olsr_param(char *key, char *value);
 
 void free_name_entry_list(struct name_entry **list);
 
-olsr_bool allowed_ip(const union olsr_ip_addr *addr);
+bool allowed_ip(const union olsr_ip_addr *addr);
 
-olsr_bool allowed_service(const char *service_line);
+bool allowed_service(const char *service_line);
 
-olsr_bool is_name_wellformed(const char *service_line);
+bool is_name_wellformed(const char *service_line);
 
-olsr_bool is_service_wellformed(const char *service_line);
+bool is_service_wellformed(const char *service_line);
 
-olsr_bool is_service_wellformed(const char *service_line);
+bool is_mac_wellformed(const char *service_line);
 
-olsr_bool is_latlon_wellformed(const char *latlon_line);
+bool is_latlon_wellformed(const char *latlon_line);
 
-olsr_bool get_isdefhna_latlon(void);
+bool get_isdefhna_latlon(void);
 
 void lookup_defhna_latlon(union olsr_ip_addr *ip);
 
@@ -181,7 +181,7 @@ void name_destructor(void);
 
 int name_init(void);
 
-#endif
+#endif /* _NAMESERVICE_PLUGIN */
 
 /*
  * Local Variables:
