@@ -52,7 +52,6 @@
 #include <fcntl.h>
 #include <linux/if_ether.h>     /* ETH_P_IP */
 #include <linux/if_packet.h>    /* struct sockaddr_ll, PACKET_MULTICAST */
-//#include <pthread.h> /* pthread_t, pthread_create() */
 #include <signal.h>             /* sigset_t, sigfillset(), sigdelset(), SIGINT */
 #include <netinet/ip.h>         /* struct ip */
 #include <netinet/udp.h>        /* struct udphdr */
@@ -100,7 +99,9 @@ bool is_broadcast(const struct sockaddr_in addr);
 bool is_multicast(const struct sockaddr_in addr);
 char * get_ipv4_str(uint32_t address, char *s, size_t maxlen);
 char * get_ipv6_str(unsigned char* address, char *s, size_t maxlen);
+#ifdef INCLUDE_DEBUG_OUTPUT
 void dump_packet(unsigned char* packet, int length);
+#endif /* INCLUDE_DEBUG_OUTPUT */
 bool check_and_mark_recent_packet(unsigned char *data, int len);
 
 /* -------------------------------------------------------------------------
@@ -173,13 +174,16 @@ PacketReceivedFromOLSR(unsigned char *encapsulationUdpData, int len)
          */
 
         if (IsMulticastv4(ipHeader)) {
+          in_addr_t addr = ntohl(ipHeader->ip_dst.s_addr);
+
           dest.sll_addr[0] = 0x01;
           dest.sll_addr[1] = 0x00;
           dest.sll_addr[2] = 0x5E;
-          dest.sll_addr[3] = (ipHeader->ip_dst.s_addr >> 16) & 0x7F;
-          dest.sll_addr[4] = (ipHeader->ip_dst.s_addr >> 8) & 0xFF;
-          dest.sll_addr[5] = ipHeader->ip_dst.s_addr & 0xFF;
-        } else /* if (IsBroadcast(ipHeader)) */ {
+          dest.sll_addr[3] = (addr >> 16) & 0x7F;
+          dest.sll_addr[4] = (addr >>  8) & 0xFF;
+          dest.sll_addr[5] = addr & 0xFF;
+        } else {
+          /* broadcast or whatever */
           memset(dest.sll_addr, 0xFF, IFHWADDRLEN);
         }
       } else /*(olsr_cnf->ip_version == AF_INET6) */ {
@@ -212,7 +216,7 @@ PacketReceivedFromOLSR(unsigned char *encapsulationUdpData, int len)
                                      sizeof(tmp)),
                         destPort);
           }
-#endif
+#endif /* INCLUDE_DEBUG_OUTPUT */
         }
       } else /* (olsr_cnf->ip_version == AF_INET6) */ {
         if (ip6Header->ip6_nxt == SOL_UDP && !IsIpv6Fragment(ip6Header)) {
@@ -231,7 +235,7 @@ PacketReceivedFromOLSR(unsigned char *encapsulationUdpData, int len)
                                      sizeof(tmp)),
                         destPort);
           }
-#endif
+#endif /* INCLUDE_DEBUG_OUTPUT */
         }
       }
 
@@ -523,7 +527,7 @@ P2pdPError(const char *format, ...)
 
 #if !defined REMOVE_LOG_DEBUG
   char *stringErr = strerror(errno);
-#endif
+#endif /* !defined REMOVE_LOG_DEBUG */
 
   /* Rely on short-circuit boolean evaluation */
   if (format == NULL || *format == '\0') {
@@ -539,7 +543,7 @@ P2pdPError(const char *format, ...)
 
 #if !defined REMOVE_LOG_DEBUG
     OLSR_DEBUG(LOG_PLUGINS, "%s: %s\n", strDesc, stringErr);
-#endif
+#endif /* !defined REMOVE_LOG_DEBUG */
   }
 }                               /* P2pdPError */
 
@@ -630,7 +634,7 @@ P2pdPacketCaptured(unsigned char *encapsulationUdpData, int nBytes)
       /* Not UDP */
 #ifdef INCLUDE_DEBUG_OUTPUT
       OLSR_PRINTF(1,"%s: NON UDP PACKET\n", PLUGIN_NAME_SHORT);
-#endif
+#endif /* INCLUDE_DEBUG_OUTPUT */
       return;                   /* for */
     }
 
@@ -639,7 +643,7 @@ P2pdPacketCaptured(unsigned char *encapsulationUdpData, int nBytes)
     if (IsIpv4Fragment(ipHeader)) {
 #ifdef INCLUDE_DEBUG_OUTPUT
       OLSR_PRINTF(1, "%s: Is IPv4 fragment\n", PLUGIN_NAME_SHORT);
-#endif
+#endif /* INCLUDE_DEBUG_OUTPUT */
       return;
     }
 
@@ -655,7 +659,7 @@ P2pdPacketCaptured(unsigned char *encapsulationUdpData, int nBytes)
       char tmp[32];
       OLSR_PRINTF(1, "%s: Not in dest/port list: %s:%d\n", PLUGIN_NAME_SHORT,
                   get_ipv4_str(dst.v4.s_addr, tmp, sizeof(tmp)), destPort);
-#endif
+#endif /* INCLUDE_DEBUG_OUTPUT */
        return;
     }
   }                            //END IPV4
@@ -681,7 +685,7 @@ P2pdPacketCaptured(unsigned char *encapsulationUdpData, int nBytes)
     if (IsIpv6Fragment(ipHeader6)) {
 #ifdef INCLUDE_DEBUG_OUTPUT
       OLSR_PRINTF(1, "%s: Is IPv6 fragment\n", PLUGIN_NAME_SHORT);
-#endif
+#endif /* INCLUDE_DEBUG_OUTPUT */
       return;
     }
 
@@ -696,7 +700,7 @@ P2pdPacketCaptured(unsigned char *encapsulationUdpData, int nBytes)
       char tmp[64];
       OLSR_PRINTF(1, "%s: Not in dest/port list: %s:%d\n", PLUGIN_NAME_SHORT,
                   get_ipv6_str(dst.v6.s6_addr, tmp, sizeof(tmp)), destPort);
-#endif
+#endif /* INCLUDE_DEBUG_OUTPUT */
       return;
     }
   }                             //END IPV6
@@ -737,7 +741,7 @@ DoP2pd(int skfd,
                       0, (struct sockaddr *)&pktAddr, &addrLen);
 #ifdef INCLUDE_DEBUG_OUTPUT
     OLSR_PRINTF(1, "%s: Received %d bytes\n", PLUGIN_NAME_SHORT, nBytes);
-#endif
+#endif /* INCLUDE_DEBUG_OUTPUT */
 
     if (nBytes < 0) {
 
@@ -769,7 +773,7 @@ DoP2pd(int skfd,
       OLSR_PRINTF(1, "%s: Multicast or broadcast packet was captured.\n",
                   PLUGIN_NAME_SHORT);
       dump_packet(ipPacket, nBytes);
-#endif
+#endif /* INCLUDE_DEBUG_OUTPUT */
       /* A multicast or broadcast packet was captured */
       P2pdPacketCaptured(ipPacket, nBytes);
 
@@ -901,12 +905,6 @@ AddUdpDestPort(const char *value,
   // IPv4 broadcast or IPv6 multicast.
 
   switch (ip_version) {
-  case AF_INET:
-    res = inet_pton(AF_INET, destAddr, &addr4.sin_addr);
-    if (!is_broadcast(addr4) && !is_multicast(addr4)) {
-      OLSR_PRINTF(1,"WARNING: IPv4 address must be multicast or broadcast... ");
-    }
-    break;
   case AF_INET6:
     res = inet_pton(AF_INET6, destAddr, &addr6.sin6_addr);
     if (addr6.sin6_addr.s6_addr[0] != 0xFF) {
@@ -914,6 +912,12 @@ AddUdpDestPort(const char *value,
       return -1;
     }
     break;
+  default:
+    res = inet_pton(AF_INET, destAddr, &addr4.sin_addr);
+    if (!is_broadcast(addr4) && !is_multicast(addr4)) {
+      OLSR_PRINTF(1,"WARNING: IPv4 address must be multicast or broadcast... ");
+    }
+    break;
   }
   // Determine whether it is a valid IP address
   if (res == 0) {
@@ -930,14 +934,14 @@ AddUdpDestPort(const char *value,
 
   new->ip_version = ip_version;
   switch (ip_version) {
-  case AF_INET:
-    new->address.v4.s_addr = addr4.sin_addr.s_addr;
-    break;
   case AF_INET6:
     memcpy(&new->address.v6.s6_addr,
            &addr6.sin6_addr.s6_addr,
            sizeof(addr6.sin6_addr.s6_addr));
     break;
+  default:
+    new->address.v4.s_addr = addr4.sin_addr.s_addr;
+    break;
   }
   new->port = destPort;
   new->next = UdpDestPortList;
@@ -1046,7 +1050,7 @@ dump_packet(unsigned char* packet, int length)
   }
   OLSR_PRINTF(1, "\n");
 }
-#endif
+#endif /* INCLUDE_DEBUG_OUTPUT */
 
 /* -------------------------------------------------------------------------
  * Function   : check_and_mark_recent_packet
