@@ -39,6 +39,7 @@
  */
 
 #include "olsrd_conf.h"
+#include "builddata.h"
 #include "../ipcalc.h"
 #include "../net_olsr.h"
 #include "../common/autobuf.h"
@@ -118,9 +119,9 @@ static void olsrd_write_if_autobuf(struct autobuf *out, struct if_config_options
   if (comments) abuf_puts(out,
     "    \n"
     "    # IPv4 broadcast address for outgoing OLSR packets.\n"
-    "    # One usefull example would be 255.255.255.255\n"
+    "    # One useful example would be 255.255.255.255\n"
     "    # The second useful value would be to\n"
-    "    # specify the peer adress of an ptp-tunnel.\n"
+    "    # specify the peer address of an ptp-tunnel.\n"
     "    # another name of this parameter is \"IPv4Multicast\"\n"
     "    # (default is 0.0.0.0, which triggers the usage of the\n"
     "    # interface broadcast IP)\n"
@@ -162,28 +163,28 @@ static void olsrd_write_if_autobuf(struct autobuf *out, struct if_config_options
     "    \n");
   if_appendf(out, comments, "    %sHelloInterval       %3.1f\n",
       cnfi->hello_params.emission_interval == HELLO_INTERVAL ? "# " : "",
-      cnfi->hello_params.emission_interval);
+      (double)cnfi->hello_params.emission_interval);
   if_appendf(out, comments, "    %sHelloValidityTime   %3.1f\n",
       cnfi->hello_params.validity_time == NEIGHB_HOLD_TIME ? "# " : "",
-      cnfi->hello_params.validity_time);
+      (double)cnfi->hello_params.validity_time);
   if_appendf(out, comments, "    %sTcInterval          %3.1f\n",
       cnfi->tc_params.emission_interval == TC_INTERVAL ? "# " : "",
-      cnfi->tc_params.emission_interval);
+      (double)cnfi->tc_params.emission_interval);
   if_appendf(out, comments, "    %sTcValidityTime      %3.1f\n",
       cnfi->tc_params.validity_time == TOP_HOLD_TIME ? "# " : "",
-      cnfi->tc_params.validity_time);
+      (double)cnfi->tc_params.validity_time);
   if_appendf(out, comments, "    %sMidInterval         %3.1f\n",
       cnfi->mid_params.emission_interval == MID_INTERVAL ? "# " : "",
-      cnfi->mid_params.emission_interval);
+      (double)cnfi->mid_params.emission_interval);
   if_appendf(out, comments, "    %sMidValidityTime     %3.1f\n",
       cnfi->mid_params.validity_time == MID_HOLD_TIME ? "# " : "",
-      cnfi->mid_params.validity_time);
+      (double)cnfi->mid_params.validity_time);
   if_appendf(out, comments, "    %sHnaInterval         %3.1f\n",
       cnfi->hna_params.emission_interval == HNA_INTERVAL ? "# " : "",
-      cnfi->hna_params.emission_interval);
+      (double)cnfi->hna_params.emission_interval);
   if_appendf(out, comments, "    %sHnaValidityTime     %3.1f\n",
       cnfi->hna_params.validity_time == HNA_HOLD_TIME ? "# " : "",
-      cnfi->hna_params.validity_time);
+      (double)cnfi->hna_params.validity_time);
   if (comments) abuf_puts(out,
     "    \n"
     "    # When multiple links exist between hosts\n"
@@ -222,7 +223,7 @@ static void olsrd_write_if_autobuf(struct autobuf *out, struct if_config_options
     while (mult != NULL) {
       if_appendf(out, comments, "    LinkQualityMult    %s %0.2f\n",
           olsr_ip_to_string(&ipbuf, &mult->addr),
-          (float)(mult->value) / 65536.0);
+          (double)((float)(mult->value) / 65536.0f));
       mult = mult->next;
     }
   }
@@ -317,8 +318,8 @@ void olsrd_write_cnf_autobuf(struct autobuf *out, struct olsrd_config *cnf) {
     "# (Default is 0.05)\n"
     "\n");
   abuf_appendf(out, "%sPollrate  %.2f\n",
-      cnf->pollrate == DEF_POLLRATE ? "# " : "",
-      cnf->pollrate);
+      cnf->pollrate == (float)DEF_POLLRATE ? "# " : "",
+      (double)cnf->pollrate);
   abuf_puts(out,
     "\n"
     "# Interval to poll network interfaces for configuration changes (in seconds).\n"
@@ -326,8 +327,8 @@ void olsrd_write_cnf_autobuf(struct autobuf *out, struct olsrd_config *cnf) {
     "# (Defaults is 2.5)\n"
     "\n");
   abuf_appendf(out, "%sNicChgsPollInt  %.1f\n",
-      cnf->nic_chgs_pollrate == DEF_NICCHGPOLLRT ? "# " : "",
-      cnf->nic_chgs_pollrate);
+      cnf->nic_chgs_pollrate == (float)DEF_NICCHGPOLLRT ? "# " : "",
+      (double)cnf->nic_chgs_pollrate);
   abuf_puts(out,
     "\n"
     "# TOS(type of service) value for the IP header of control traffic.\n"
@@ -436,6 +437,88 @@ void olsrd_write_cnf_autobuf(struct autobuf *out, struct olsrd_config *cnf) {
   abuf_appendf(out, "%sSmartGateway %s\n",
       cnf->smart_gw_active == DEF_SMART_GW ? "# " : "",
       cnf->smart_gw_active ? "yes" : "no");
+  abuf_puts(out,
+    "\n"
+    "# Signals that the server tunnel must always be removed on shutdown,\n"
+    "# irrespective of the interface up/down state during startup.\n"
+    "# (default is \"no\")\n"
+    "\n");
+  abuf_appendf(out, "%sSmartGatewayAlwaysRemoveServerTunnel %s\n",
+      cnf->smart_gw_always_remove_server_tunnel == DEF_SMART_GW_ALWAYS_REMOVE_SERVER_TUNNEL ? "# " : "",
+      cnf->smart_gw_always_remove_server_tunnel ? "yes" : "no");
+  abuf_puts(out,
+    "\n"
+    "# Determines the maximum number of gateways that can be in use at any given\n"
+    "# time. This setting is used to mitigate the effects of breaking connections\n"
+    "# (due to the selection of a new gateway) on a dynamic network.\n"
+    "# (default is 1)\n"
+    "\n");
+  abuf_appendf(out, "%sSmartGatewayUseCount %d\n",
+      cnf->smart_gw_use_count == DEF_GW_USE_COUNT ? "# " : "",
+      cnf->smart_gw_use_count);
+  abuf_puts(out,
+    "\n"
+    "# Determines the take-down percentage for a non-current smart gateway tunnel.\n"
+    "# If the cost of the current smart gateway tunnel is less than this percentage\n"
+    "# of the cost of the non-current smart gateway tunnel, then the non-current smart\n"
+    "# gateway tunnel is taken down because it is then presumed to be 'too expensive'.\n"
+    "# This setting is only relevant when SmartGatewayUseCount is larger than 1;\n"
+    "# a value of 0 will result in the tunnels not being taken down proactively.\n"
+    "# (default is 0)\n"
+    "\n");
+  abuf_appendf(out, "%sSmartGatewayTakeDownPercentage %d\n",
+      cnf->smart_gw_takedown_percentage == DEF_GW_TAKEDOWN_PERCENTAGE ? "# " : "",
+      cnf->smart_gw_takedown_percentage);
+  abuf_puts(out,
+    "\n"
+    "# Determines the policy routing script that is executed during startup and\n"
+    "# shutdown of olsrd. The script is only executed when SmartGatewayUseCount\n"
+    "# is set to a value larger than 1. The script must setup policy routing\n"
+    "# rules such that multi-gateway mode works. A sample script is included.\n"
+    "# (default is not set)\n"
+    "\n");
+  abuf_appendf(out, "%sSmartGatewayPolicyRoutingScript %s\n",
+      !cnf->smart_gw_policyrouting_script ? "# " : "",
+      !cnf->smart_gw_policyrouting_script ? "" : cnf->smart_gw_policyrouting_script);
+  abuf_puts(out,
+    "\n"
+    "# Determines the egress interfaces that are part of the multi-gateway setup and\n"
+    "# therefore only relevant when SmartGatewayUseCount is larger than 1 (in which\n"
+    "# case it must be explicitly set).\n"
+    "# (default is not set)\n"
+    "\n");
+  abuf_appendf(out, "%sSmartGatewayEgressInterfaces",
+      !cnf->smart_gw_egress_interfaces ? "# " : "");
+  {
+    struct sgw_egress_if * sgwegressif = olsr_cnf->smart_gw_egress_interfaces;
+    while (sgwegressif) {
+      abuf_appendf(out, " \"%s\"", sgwegressif->name);
+      sgwegressif = sgwegressif->next;
+    }
+    abuf_puts(out, "\n");
+  }
+  abuf_puts(out,
+    "\n"
+    "# Determines the offset of the smart gateway egress interfaces mark that are\n"
+    "# used in the policy routing rules in a multi-gateway setup. Only relevant\n"
+    "# when a multi-gateway setup is used.\n"
+    "# (default is 91)\n"
+    "\n");
+  abuf_appendf(out, "%sSmartGatewayMarkOffsetEgress %u\n",
+      cnf->smart_gw_mark_offset_egress == DEF_GW_MARK_OFFSET_EGRESS ? "# " : "",
+      cnf->smart_gw_mark_offset_egress);
+  abuf_puts(out,
+    "\n"
+    "# Determines the offset of the smart gateway tunnel interfaces mark that are\n"
+    "# used in the policy routing rules in a multi-gateway setup. Only relevant\n"
+    "# when a multi-gateway setup is used.\n"
+    "# The ranges [egress offset, egress offset + egress count] and\n"
+    "# [tunnel offset, tunnel offset + use count] are not allowed to overlap.\n"
+    "# (default is 101)\n"
+    "\n");
+  abuf_appendf(out, "%sSmartGatewayMarkOffsetTunnels %u\n",
+      cnf->smart_gw_mark_offset_tunnels == DEF_GW_MARK_OFFSET_TUNNELS ? "# " : "",
+      cnf->smart_gw_mark_offset_tunnels);
   abuf_puts(out,
     "\n"
     "# Allows the selection of a smartgateway with NAT (only for IPv4)\n"
@@ -444,6 +527,71 @@ void olsrd_write_cnf_autobuf(struct autobuf *out, struct olsrd_config *cnf) {
   abuf_appendf(out, "%sSmartGatewayAllowNAT %s\n",
       cnf->smart_gw_allow_nat == DEF_GW_ALLOW_NAT ? "# " : "",
       cnf->smart_gw_allow_nat ? "yes" : "no");
+  abuf_puts(out,
+    "\n"
+    "# Determines the period (in milliseconds) on which a new smart gateway\n"
+    "# selection is performed.\n"
+    "# (default is 10000 milliseconds)\n"
+    "\n");
+  abuf_appendf(out, "%sSmartGatewayPeriod %d\n",
+      cnf->smart_gw_period == DEF_GW_PERIOD ? "# " : "",
+      cnf->smart_gw_period);
+  abuf_puts(out,
+    "\n"
+    "# Determines the number of times the link state database must be stable\n"
+    "# before a new smart gateway is selected.\n"
+    "# (default is 6)\n"
+    "\n");
+  abuf_appendf(out, "%sSmartGatewayStableCount %d\n",
+      cnf->smart_gw_stablecount == DEF_GW_STABLE_COUNT ? "# " : "",
+      cnf->smart_gw_stablecount);
+  abuf_puts(out,
+    "\n"
+    "# When another gateway than the current one has a cost of less than the cost\n"
+    "# of the current gateway multiplied by SmartGatewayThreshold then the smart\n"
+    "# gateway is switched to the other gateway. The unit is percentage.\n"
+    "# (defaults to 0)\n"
+    "\n");
+  abuf_appendf(out, "%sSmartGatewayThreshold  %d\n",
+      cnf->smart_gw_thresh == DEF_GW_THRESH ? "# " : "",
+      cnf->smart_gw_thresh);
+  abuf_puts(out,
+    "\n"
+    "# The weighing factor for the gateway uplink bandwidth (exit link, uplink).\n"
+    "# See README-Olsr-Extensions for a description of smart gateways.\n"
+    "# (default is 1)\n"
+    "\n");
+  abuf_appendf(out, "%sSmartGatewayWeightExitLinkUp  %d\n",
+      cnf->smart_gw_weight_exitlink_up == DEF_GW_WEIGHT_EXITLINK_UP ? "# " : "",
+      cnf->smart_gw_weight_exitlink_up);
+  abuf_puts(out,
+    "\n"
+    "# The weighing factor for the gateway downlink bandwidth (exit link, downlink).\n"
+    "# See README-Olsr-Extensions for a description of smart gateways.\n"
+    "# (default is 1)\n"
+    "\n");
+  abuf_appendf(out, "%sSmartGatewayWeightExitLinkDown  %d\n",
+      cnf->smart_gw_weight_exitlink_down == DEF_GW_WEIGHT_EXITLINK_DOWN ? "# " : "",
+      cnf->smart_gw_weight_exitlink_down);
+  abuf_puts(out,
+    "\n"
+    "# The weighing factor for the ETX costs.\n"
+    "# See README-Olsr-Extensions for a description of smart gateways.\n"
+    "# (default is 1)\n"
+    "\n");
+  abuf_appendf(out, "%sSmartGatewayWeightEtx  %d\n",
+      cnf->smart_gw_weight_etx == DEF_GW_WEIGHT_ETX ? "# " : "",
+      cnf->smart_gw_weight_etx);
+
+  abuf_puts(out,
+    "\n"
+    "# The divider for the ETX costs.\n"
+    "# See README-Olsr-Extensions for a description of smart gateways.\n"
+    "# (default is 0)\n"
+    "\n");
+  abuf_appendf(out, "%sSmartGatewayDividerEtx  %d\n",
+      cnf->smart_gw_divider_etx == DEF_GW_DIVIDER_ETX ? "# " : "",
+      cnf->smart_gw_divider_etx);
   abuf_puts(out,
     "\n"
     "# Defines what kind of Uplink this node will publish as a\n"
@@ -552,14 +700,14 @@ void olsrd_write_cnf_autobuf(struct autobuf *out, struct olsrd_config *cnf) {
     "# (default is 0.5/0.8/0.3)\n"
     "\n");
   abuf_appendf(out, "%sHystScaling  %.2f\n",
-      cnf->hysteresis_param.scaling == HYST_SCALING ? "# " : "",
-      cnf->hysteresis_param.scaling);
+      cnf->hysteresis_param.scaling == (float)HYST_SCALING ? "# " : "",
+      (double)cnf->hysteresis_param.scaling);
   abuf_appendf(out, "%sHystThrHigh  %.2f\n",
-      cnf->hysteresis_param.thr_high == HYST_THRESHOLD_HIGH ? "# " : "",
-      cnf->hysteresis_param.thr_high);
+      cnf->hysteresis_param.thr_high == (float)HYST_THRESHOLD_HIGH ? "# " : "",
+      (double)cnf->hysteresis_param.thr_high);
   abuf_appendf(out, "%sHystThrLow  %.2f\n",
-      cnf->hysteresis_param.thr_low == HYST_THRESHOLD_LOW ? "# " : "",
-      cnf->hysteresis_param.thr_low);
+      cnf->hysteresis_param.thr_low == (float)HYST_THRESHOLD_LOW ? "# " : "",
+      (double)cnf->hysteresis_param.thr_low);
   abuf_puts(out,
     "\n"
     "# TC redundancy\n"
@@ -624,8 +772,8 @@ void olsrd_write_cnf_autobuf(struct autobuf *out, struct olsrd_config *cnf) {
     "# (default is 0.05)\n"
     "\n");
   abuf_appendf(out, "%sLinkQualityAging %.2f\n",
-      cnf->lq_aging == DEF_LQ_AGING ? "# " : "",
-      cnf->lq_aging);
+      cnf->lq_aging == (float)DEF_LQ_AGING ? "# " : "",
+      (double)cnf->lq_aging);
   abuf_puts(out,
     "\n"
     "# Fisheye mechanism for TCs (0 meansoff, 1 means on)\n"
@@ -651,8 +799,8 @@ void olsrd_write_cnf_autobuf(struct autobuf *out, struct olsrd_config *cnf) {
     "# (defaults to 1.0)\n"
     "\n");
   abuf_appendf(out, "%sNatThreshold  %.1f\n",
-      cnf->lq_nat_thresh == DEF_LQ_NAT_THRESH ? "# " : "",
-      cnf->lq_nat_thresh);
+      cnf->lq_nat_thresh == (float)DEF_LQ_NAT_THRESH ? "# " : "",
+      (double)cnf->lq_nat_thresh);
 
   abuf_puts(out,
     "\n"
