@@ -44,6 +44,9 @@
 
 #include "olsr_types.h"
 #include "common/autobuf.h"
+#ifdef HTTPINFO_PUD
+#include "pud/src/receiver.h"
+#endif /* HTTPINFO_PUD */
 
 /* set to 1 to collect all startup sleep into one sleep
  * (just as long as the longest sleep)
@@ -78,7 +81,19 @@
 #define DEF_MIN_TC_VTIME     0.0
 #define DEF_USE_NIIT         true
 #define DEF_SMART_GW         false
+#define DEF_SMART_GW_ALWAYS_REMOVE_SERVER_TUNNEL  false
+#define DEF_GW_USE_COUNT     1
+#define DEF_GW_TAKEDOWN_PERCENTAGE 25
+#define DEF_GW_MARK_OFFSET_EGRESS   91
+#define DEF_GW_MARK_OFFSET_TUNNELS 101
+#define DEF_GW_PERIOD        10*1000
+#define DEF_GW_STABLE_COUNT  6
 #define DEF_GW_ALLOW_NAT     true
+#define DEF_GW_THRESH        0
+#define DEF_GW_WEIGHT_EXITLINK_UP   1
+#define DEF_GW_WEIGHT_EXITLINK_DOWN 1
+#define DEF_GW_WEIGHT_ETX           1
+#define DEF_GW_DIVIDER_ETX          0
 #define DEF_GW_TYPE          GW_UPLINK_IPV46
 #define DEF_GW_UPLINK_NAT    true
 #define DEF_UPLINK_SPEED     128
@@ -112,12 +127,26 @@
 #define MAX_LQ_AGING         1.0
 #define MIN_LQ_AGING         0.01
 
+#define MIN_SMARTGW_USE_COUNT_MIN  1
+#define MAX_SMARTGW_USE_COUNT_MAX  64
+
+#define MAX_SMARTGW_EGRESS_INTERFACE_COUNT_MAX 32
+
+#define MIN_SMARTGW_PERIOD   1*1000
+#define MAX_SMARTGW_PERIOD   320000*1000
+
+#define MIN_SMARTGW_STABLE   1
+#define MAX_SMARTGW_STABLE   254
+
+#define MIN_SMARTGW_THRES    10
+#define MAX_SMARTGW_THRES    100
+
 #define MIN_SMARTGW_SPEED    1
 #define MAX_SMARTGW_SPEED    320000000
 
 #ifndef IPV6_ADDR_SITELOCAL
 #define IPV6_ADDR_SITELOCAL    0x0040U
-#endif
+#endif /* IPV6_ADDR_SITELOCAL */
 
 #include "interfaces.h"
 
@@ -212,6 +241,12 @@ struct plugin_entry {
   struct plugin_entry *next;
 };
 
+struct sgw_egress_if {
+  char *name;
+  uint8_t mark;
+  struct sgw_egress_if *next;
+};
+
 /*
  * The config struct
  */
@@ -220,6 +255,7 @@ struct olsrd_config {
   uint16_t olsrport;
   int debug_level;
   bool no_fork;
+  char * pidfile;
   bool host_emul;
   int ip_version;
   bool allow_no_interfaces;
@@ -251,10 +287,26 @@ struct olsrd_config {
 
   float min_tc_vtime;
 
+  bool set_ip_forward;
+
   char *lock_file;
   bool use_niit;
 
-  bool smart_gw_active, smart_gw_allow_nat, smart_gw_uplink_nat;
+  bool smart_gw_active, smart_gw_always_remove_server_tunnel, smart_gw_allow_nat, smart_gw_uplink_nat;
+  uint8_t smart_gw_use_count;
+  uint8_t smart_gw_takedown_percentage;
+  char *smart_gw_policyrouting_script;
+  struct sgw_egress_if * smart_gw_egress_interfaces;
+  uint8_t smart_gw_egress_interfaces_count;
+  uint8_t smart_gw_mark_offset_egress;
+  uint8_t smart_gw_mark_offset_tunnels;
+  uint32_t smart_gw_period;
+  uint8_t smart_gw_stablecount;
+  uint8_t smart_gw_thresh;
+  uint8_t smart_gw_weight_exitlink_up;
+  uint8_t smart_gw_weight_exitlink_down;
+  uint8_t smart_gw_weight_etx;
+  uint8_t smart_gw_divider_etx;
   enum smart_gw_uplinktype smart_gw_type;
   uint32_t smart_gw_uplink, smart_gw_downlink;
   struct olsr_ip_prefix smart_gw_prefix;
@@ -278,20 +330,24 @@ struct olsrd_config {
   bool has_ipv4_gateway, has_ipv6_gateway;
 
   int ioctl_s;                         /* Socket used for ioctl calls */
-#ifdef LINUX_NETLINK_ROUTING
+#ifdef __linux__
   int rtnl_s;                          /* Socket used for rtnetlink messages */
   int rt_monitor_socket;
-#endif
+#endif /* __linux__ */
 
-#if defined __FreeBSD__ || defined __FreeBSD_kernel__ || defined __MacOSX__ || defined __NetBSD__ || defined __OpenBSD__
+#if defined __FreeBSD__ || defined __FreeBSD_kernel__ || defined __APPLE__ || defined __NetBSD__ || defined __OpenBSD__
   int rts;                             /* Socket used for route changes on BSDs */
-#endif
+#endif /* defined __FreeBSD__ || defined __FreeBSD_kernel__ || defined __APPLE__ || defined __NetBSD__ || defined __OpenBSD__ */
   float lq_nat_thresh;
+
+#ifdef HTTPINFO_PUD
+  TransmitGpsInformation * pud_position;
+#endif /* HTTPINFO_PUD */
 };
 
 #if defined __cplusplus
 extern "C" {
-#endif
+#endif /* defined __cplusplus */
 
   extern const char *GW_UPLINK_TXT[];
   extern const char *FIB_METRIC_TXT[];
@@ -327,18 +383,18 @@ extern "C" {
 
   struct olsrd_config *olsrd_get_default_cnf(void);
 
-#if defined WIN32
+#if defined _WIN32
   void win32_stdio_hack(unsigned int);
 
   void *win32_olsrd_malloc(size_t size);
 
   void win32_olsrd_free(void *ptr);
-#endif
+#endif /* defined _WIN32 */
 
 #if defined __cplusplus
 }
-#endif
-#endif
+#endif /* defined __cplusplus */
+#endif /* _OLSRD_CFGPARSER_H */
 
 /*
  * Local Variables:
