@@ -81,26 +81,27 @@ olsr_load_plugins(void)
  *the required information
  *
  *@param libname the name of the library(file)
+ *@param params plugin parameters
  *
  *@return negative on error
  */
 static int
 olsr_load_dl(char *libname, struct plugin_param *params)
 {
-#if TESTLIB_PATH
+#if defined TESTLIB_PATH && TESTLIB_PATH
   char path[256] = "/usr/testlib/";
-#endif
+#endif /* defined TESTLIB_PATH && TESTLIB_PATH */
   struct olsr_plugin *plugin = olsr_malloc(sizeof(struct olsr_plugin), "Plugin entry");
   int rv;
 
   OLSR_PRINTF(0, "---------- LOADING LIBRARY %s ----------\n", libname);
 
-#if TESTLIB_PATH
+#if defined TESTLIB_PATH && TESTLIB_PATH
   strcat(path, libname);
   plugin->dlhandle = dlopen(path, RTLD_NOW);
-#else
+#else /* defined TESTLIB_PATH && TESTLIB_PATH */
   plugin->dlhandle = dlopen(libname, RTLD_NOW);
-#endif
+#endif /* defined TESTLIB_PATH && TESTLIB_PATH */
   if (plugin->dlhandle == NULL) {
     const int save_errno = errno;
     OLSR_PRINTF(0, "DL loading failed: \"%s\"!\n", dlerror());
@@ -131,7 +132,7 @@ olsr_load_dl(char *libname, struct plugin_param *params)
   return rv;
 }
 
-#if SUPPORT_OLD_PLUGIN_VERSIONS
+#if defined SUPPORT_OLD_PLUGIN_VERSIONS && SUPPORT_OLD_PLUGIN_VERSIONS
 static int
 try_old_versions(const struct olsr_plugin *plugin)
 {
@@ -152,9 +153,9 @@ try_old_versions(const struct olsr_plugin *plugin)
   OLSR_PRINTF(0, "FAILED: \"%s\"\n", dlerror());
   return -1;
 }
-#else
+#else /* defined SUPPORT_OLD_PLUGIN_VERSIONS && SUPPORT_OLD_PLUGIN_VERSIONS */
 #define try_old_versions(plugin) -1
-#endif
+#endif /* defined SUPPORT_OLD_PLUGIN_VERSIONS && SUPPORT_OLD_PLUGIN_VERSIONS */
 
 static int
 olsr_add_dl(struct olsr_plugin *plugin)
@@ -183,14 +184,14 @@ olsr_add_dl(struct olsr_plugin *plugin)
                 "\nWARNING: YOU ARE USING AN OLD DEPRECATED PLUGIN INTERFACE!\n"
                 "DETECTED VERSION %d AND THE CURRENT VERSION IS %d\n" "PLEASE UPGRADE YOUR PLUGIN!\n", plugin_interface_version,
                 MOST_RECENT_PLUGIN_INTERFACE_VERSION);
-#if SUPPORT_OLD_PLUGIN_VERSIONS
+#if defined SUPPORT_OLD_PLUGIN_VERSIONS && SUPPORT_OLD_PLUGIN_VERSIONS
     OLSR_PRINTF(0, "WILL CONTINUE IN 5 SECONDS...\n\n");
     sleep(5);
-#else
+#else /* defined SUPPORT_OLD_PLUGIN_VERSIONS && SUPPORT_OLD_PLUGIN_VERSIONS */
     return -1;
-#endif
+#endif /* defined SUPPORT_OLD_PLUGIN_VERSIONS && SUPPORT_OLD_PLUGIN_VERSIONS */
   }
-#if SUPPORT_OLD_PLUGIN_VERSIONS
+#if defined SUPPORT_OLD_PLUGIN_VERSIONS && SUPPORT_OLD_PLUGIN_VERSIONS
   /* new plugin interface */
   if (plugin_interface_version < LAST_SUPPORTED_PLUGIN_INTERFACE_VERSION) {
     OLSR_PRINTF(0,
@@ -199,7 +200,7 @@ olsr_add_dl(struct olsr_plugin *plugin)
                 LAST_SUPPORTED_PLUGIN_INTERFACE_VERSION);
     sleep(5);
   }
-#endif
+#endif /* defined SUPPORT_OLD_PLUGIN_VERSIONS && SUPPORT_OLD_PLUGIN_VERSIONS */
 
   /* Fetch the init function */
   OLSR_PRINTF(1, "Trying to fetch plugin init function: ");
@@ -216,7 +217,7 @@ olsr_add_dl(struct olsr_plugin *plugin)
   if (get_plugin_parameters != NULL) {
     (*get_plugin_parameters) (&plugin->plugin_parameters, &plugin->plugin_parameters_size);
   } else {
-#if SUPPORT_OLD_PLUGIN_VERSIONS
+#if defined SUPPORT_OLD_PLUGIN_VERSIONS && SUPPORT_OLD_PLUGIN_VERSIONS
     /* Fetch the parameter function */
     OLSR_PRINTF(1, "Trying to fetch param function: ");
 
@@ -230,10 +231,10 @@ olsr_add_dl(struct olsr_plugin *plugin)
 
     plugin->plugin_parameters = NULL;
     plugin->plugin_parameters_size = 0;
-#else
+#else /* defined SUPPORT_OLD_PLUGIN_VERSIONS && SUPPORT_OLD_PLUGIN_VERSIONS */
     OLSR_PRINTF(0, "Old plugin interfaces are not supported\n");
     return -1;
-#endif
+#endif /* defined SUPPORT_OLD_PLUGIN_VERSIONS && SUPPORT_OLD_PLUGIN_VERSIONS */
   }
   return 0;
 }
@@ -282,7 +283,7 @@ init_olsr_plugin(struct olsr_plugin *entry)
           rv = -1;
         }
       }
-#if SUPPORT_OLD_PLUGIN_VERSIONS
+#if defined SUPPORT_OLD_PLUGIN_VERSIONS && SUPPORT_OLD_PLUGIN_VERSIONS
     } else if (entry->register_param != NULL) {
       int rc;
       OLSR_PRINTF(0, "Registering parameter \"%s\": ", params->key);
@@ -292,7 +293,7 @@ init_olsr_plugin(struct olsr_plugin *entry)
         exit(EXIT_FAILURE);
       }
       OLSR_PRINTF(0, "%s\n", rc == 0 ? "FAILED" : "OK");
-#endif
+#endif /* defined SUPPORT_OLD_PLUGIN_VERSIONS && SUPPORT_OLD_PLUGIN_VERSIONS */
     } else {
       OLSR_PRINTF(0, "I don't know what to do with \"%s\"!\n", params->key);
       rv = -1;
