@@ -246,7 +246,7 @@ process_message_neighbors(struct neighbor_entry *neighbor, const struct hello_me
  *
  *@param neighbor the 1-hop neighbor
  *@param two_hop_neighbor the 2-hop neighbor
- *@return nada
+ *@param vtime the validity time
  */
 static void
 linking_this_2_entries(struct neighbor_entry *neighbor, struct neighbor_2_entry *two_hop_neighbor, olsr_reltime vtime)
@@ -285,7 +285,7 @@ linking_this_2_entries(struct neighbor_entry *neighbor, struct neighbor_2_entry
  * Check if a hello message states this node as a MPR.
  *
  * @param message the message to check
- * @param n_link the buffer to put the link status in
+ * @param in_if the incoming interface
  *
  *@return 1 if we are selected as MPR 0 if not
  */
@@ -427,7 +427,7 @@ olsr_hello_tap(struct hello_message *message, struct interface *in_if, const uni
       else
       {
         struct ipaddr_str srcbuf, origbuf;
-        olsr_syslog(OLSR_LOG_INFO, "got hello with invalid from and originator adress pair (%s, %s) Duplicate Ips?\n",
+        olsr_syslog(OLSR_LOG_INFO, "got hello with invalid from and originator address pair (%s, %s) Duplicate Ips?\n",
                     olsr_ip_to_string(&origbuf,&message->source_addr),
                     olsr_ip_to_string(&srcbuf,from_addr));
       }
@@ -441,21 +441,15 @@ olsr_hello_tap(struct hello_message *message, struct interface *in_if, const uni
 
     /* find the input interface in the list of neighbor interfaces */
     for (walker = message->neighbors; walker != NULL; walker = walker->next) {
-      if (walker->link != UNSPEC_LINK
-          && ipequal(&walker->address, &in_if->ip_addr)) {
+      if (ipequal(&walker->address, &in_if->ip_addr)) {
+        /*
+         * memorize our neighbour's idea of the link quality, so that we
+         * know the link quality in both directions
+         */
+        olsr_memorize_foreign_hello_lq(lnk, walker->link != UNSPEC_LINK ? walker : NULL);
         break;
       }
     }
-
-    /*
-     * memorize our neighbour's idea of the link quality, so that we
-     * know the link quality in both directions
-     *
-     * walker is NULL if there the current interface was not included in
-     * the message (or was included as an UNSPEC_LINK)
-     */
-    olsr_memorize_foreign_hello_lq(lnk, walker);
-
     /* update packet loss for link quality calculation */
     olsr_received_hello_handler(lnk);
   }
@@ -493,7 +487,7 @@ olsr_hello_tap(struct hello_message *message, struct interface *in_if, const uni
   if (neighbor->willingness != WILL_NEVER)
     process_message_neighbors(neighbor, message);
 
-  /* Process changes immedeatly in case of MPR updates */
+  /* Process changes immediately in case of MPR updates */
   olsr_process_changes();
 
   olsr_free_hello_packet(message);
